Struct SRIn

pub struct SRIn { /* private fields */ }
A type defining an interface for modules which can be connected to signals and is used by compute modules to read data from the attached signals.

Implementations

Source

impl SRIn

pub fn new() -> Self

pub fn read(&self) -> L4

pub fn attach(&mut self, signal: &Signal)

pub fn attach_resolved(&mut self, signal: &ResolvedSignal)

pub fn set_to(&mut self, other: &SRIn)

pub fn sig_id(&self) -> u128