Struct SROut

pub struct SROut { /* private fields */ }
A type defining an interface for modules which can be connected to signals and is used by compute modules to write data from the attached signals.

Implementations

Source

impl SROut

pub fn new() -> Self

pub fn write(&self, new_value: L4)

pub fn attach(&mut self, signal: &Signal)

pub fn set_to(&mut self, other: &SROut)

pub fn attach_resolved(&mut self, signal: &ResolvedSignal)