pub struct SRIn { /* private fields */ }Expand description
A type defining an interface for modules which can be connected to signals and is used by compute modules to read data from the attached signals.
Implementations