pub struct SROut { /* private fields */ }Expand description
A type defining an interface for modules which can be connected to signals and is used by compute modules to write data from the attached signals.
Implementations